<?php
if ( ! defined( 'ABSPATH' ) ) exit;

class IEBASE_HCB {

	/**
	 * DB Names
	 */
	const DB_NAME = [
		'installed' => 'iebase_hcb_installed',
		'settings'  => 'iebase_hcb_settings',
	];

	/**
	 * 設定ページのスラッグ
	 */
	const MENU_SLUG = 'hcb_settings';

	/**
	 * Default Settings (インストール時にDBへ保存)
	 */
	const DEFAULT_SETTINGS = [
		'show_lang'       => 'on',
		'show_linenum'    => 'on',
		'front_coloring'  => 'light',
		'editor_coloring' => 'light',
	];

	/**
	 * Default Languages
	 */
	const DEFAULT_LANGS = ''.
		'html:"HTML",'."\n" .
		'css:"CSS",'."\n" .
		'scss:"SCSS",'."\n" .
		'js:"JavaScript",'."\n" .
		'ts:"TypeScript",'."\n" .
		'php:"PHP",'."\n" .
		'ruby:"Ruby",'."\n" .
		'python:"Python",'."\n" .
		'swift:"Swift",'."\n" .
		'c:"C",'."\n" .
		'csharp:"C#",'."\n" .
		'cpp:"C++",'."\n" .
		'objectivec:"Objective-C",'."\n" .
		'sql:"SQL",'."\n" .
		'json:"JSON",'."\n" .
		'bash:"Bash",'."\n" .
		'git:"Git",';

	/**
	 * variables
	 */
	public static $settings = '';
	public static $prism_js_url  = '';
	public static $coloring_css_url = '';
	public static $editor_coloring_css_url = '';

	/**
	 * The constructor
	 */
	public function __construct() {
		$this->init();
		$this->set_path();
		new IEBASE_HCB_Scripts();
		new IEBASE_HCB_Mce();
		new IEBASE_HCB_Menu();

		// Set linenum
		add_filter( 'the_content' , function( $content ) {

			$content = str_replace( 'prism on-numbers', 'prism line-numbers', $content );

			//個別設定が未定義のブロックはベース設定に依存
			if ( 'on' === IEBASE_HCB::$settings[ 'show_linenum' ] ) {
				$content = str_replace( 'prism undefined-numbers', 'prism line-numbers', $content );
			}
			return $content;

		} , 99);
	}

	/**
	 * Set HCB Settings
	 */
	private function init() {

		// Get Option for HCB Setiings
		$option = get_option( self::DB_NAME[ 'settings' ] ) ?: [];

		// Changes
		if ( is_admin() && isset( $option['support_langs'] ) ) {
			
			$support_langs      = str_replace(["\r\n", "\r", "\n"], '', $option['support_langs']);
			$default_langs      = str_replace(["\n"], '', self::DEFAULT_LANGS);

			if ( $default_langs === $support_langs ) {
				unset( $option['support_langs'] );

				// DB update
				update_option( IEBASE_HCB::DB_NAME[ 'settings' ], $option );
			}
		}

		// Get default settings
		$default = self::DEFAULT_SETTINGS;
		$default['support_langs'] = self::DEFAULT_LANGS;


		// Merge to default
		self::$settings = array_merge( $default, $option );

	}


	/**
	 * Set file path
	 */
	private function set_path() {

		// Set Prism.js file url
	    self::$prism_js_url = IEBASE_HCB_URL .'assets/js/prism.js';

		// Set front coloring file url
		self::$coloring_css_url = IEBASE_HCB_URL .'assets/css/style_'. self::$settings[ 'front_coloring' ] .'.css';
		
		// Set editor coloring file url
		self::$editor_coloring_css_url = IEBASE_HCB_URL. 'assets/css/editor_'. self::$settings[ 'editor_coloring' ] . '.css';
	}
}
