<?php
if ( ! defined( 'ABSPATH' ) ) exit;

/**
 * Add HCB setting page.
 */
add_action( 'admin_menu', function() {
	$pagename = __( 'Iebase Code', 'iebase-hcb' );
	add_options_page(
		$pagename,
		$pagename,
		'manage_options',
		IEBASE_HCB::MENU_SLUG,
		['IEBASE_HCB_Menu', 'hcb_settings_cb']
	);
});

/**
 * Setting item field registration
 */
add_action( 'admin_init', function() {
	// Register the option name saved in the database
	register_setting( IEBASE_HCB::MENU_SLUG, IEBASE_HCB::DB_NAME['settings'] );

	//Basic Settings section
	add_settings_section(
		'hcb_setting_section',
		__( 'Basic settings', 'iebase-hcb' ),
		'',
		IEBASE_HCB::MENU_SLUG
	);

	$basic_sections = [
		'show_lang' => [
			'title' => __( 'Display language name', 'iebase-hcb' ),
			'args' => [
				'type' => 'checkbox',
				'label' => __( 'Display language name in code block', 'iebase-hcb' ),
				'desc' => __( 'If checked, the language type is displayed in the code on the site display side.', 'iebase-hcb' )
			]
		],
		'show_linenum' => [
			'title' => __( 'Display settings for the number of rows', 'iebase-hcb' ),
			'args' => [
				'type' => 'checkbox',
				'label' => __( 'Show line count in code block', 'iebase-hcb' ),
				'desc' => __( 'If checked, the number of lines will be displayed on the left end of the code on the site display side.', 'iebase-hcb' ), 
			]
		],
		'front_coloring' => [
			'title' => __( 'Cord coloring (front side)', 'iebase-hcb' ),
			'args' => [
				'type' => 'radio',
				'choices' => [
					'Light' => 'light',
					'Dark' => 'dark',
				]
			]
		],
		'editor_coloring' => [
			'title' => __( 'Code coloring (editor side)', 'iebase-hcb' ),
			'args' => [
				'type' => 'radio',
				'choices' => [
					'Light' => 'light',
					'Dark' => 'dark',
				]
			]
		],
	];

	foreach ( $basic_sections as $id => $data ) {
		$args = $data['args'];
		$args['id'] = $id;

		add_settings_field(
			$id,
			$data['title'],
			['IEBASE_HCB_Menu', 'settings_field_cb'],
			IEBASE_HCB::MENU_SLUG,
			'hcb_setting_section',
			$args
		);
	}

	/**
	 * Advanced Settings Settings section
	 */
	add_settings_section(
		'hcb_setting_advanced',
		__( 'Advanced settings', 'iebase-hcb' ),
		'',
		IEBASE_HCB::MENU_SLUG
	);

	$advanced_sections = [
		'support_langs' => [
			'title' => __( 'Language set to use', 'iebase-hcb' ),
			'args' => [
				'type' => 'textarea',
				'rows' => 16,
				'desc' => sprintf(
						__( 'Write in the format of %s, separated by "," (comma).', 'iebase-hcb' ),
						'<code>'. __('class-key:"language-name"', 'iebase-hcb' ) .'</code>'
					). '<br>&emsp;- '.
					__('"class-key" is the class name used in prism.js (the part corresponding to "◯◯" in "lang- ◯◯")', 'iebase-hcb' ). 
					'<br> '.__('* If you use a language that is not supported by default, please use it together with "Original prism.js" setting.', 'iebase-hcb' ),
				'after' => '<pre class="default_support_langs"><code>'. IEBASE_HCB::DEFAULT_LANGS . '</code></pre>',
			]
		],
	];

	foreach ( $advanced_sections as $id => $data ) {
		$args = $data['args'];
		$args['id'] = $id;

		add_settings_field(
			$id,
			$data['title'],
			['IEBASE_HCB_Menu', 'settings_field_cb'],
			IEBASE_HCB::MENU_SLUG,
			'hcb_setting_advanced',
			$args
		);
	}
} );


class IEBASE_HCB_Menu {

	/**
	 * hcb_settings_cb
	 */
	public static function hcb_settings_cb() {
		echo '<div class="wrap hcb_setting">'.
		'<h1>'. __( 'Iebase Code Block settings', 'iebase-hcb' ) .'</h1>'.
		'<form action="options.php" method="post">';
		do_settings_sections( IEBASE_HCB::MENU_SLUG );
		settings_fields( IEBASE_HCB::MENU_SLUG ); // Match the group name of register_setting()
		submit_button();
		echo '</form></div>';
	}

	/**
	 * Setting item field display function
	 */
	public static function settings_field_cb( $args = [] ) {

		$default = [
			'id'    => '',
			'type'   => 'input',
			'input_type'   => 'text',
			'choices' => [],
			'label' => '',
			'rows' => '',
			'before' => '',
			'after' => '',
			'desc' => '',
		];
		$args = array_merge( $default, $args );

		$type = $args['type'];
		if ( 'input' === $type ) {
			self::field_input( $args );
		} elseif ( 'radio' === $type ) {
			self::field_radio( $args );
		} elseif ( 'checkbox' === $type ) {
			self::field_checkbox( $args );
		} elseif ( 'textarea' === $type ) {
			self::field_textarea( $args );
		}

		if ( $args['desc'] ) echo '<p class="description">'. $args['desc'] .'</p>';
	}

	/**
	 * input
	 */
	private static function field_input( $args ) {

		$id = $args['id'];
		$name = IEBASE_HCB::DB_NAME['settings'] . '['. $id . ']';
		$value = IEBASE_HCB::$settings[$id];

		echo $args['before']. '<input id="' . $id . '" name="' . $name . '" type="'. $args['input_type']. '" value="'. $value .'" />'. $args['after'];

	}

	/**
	 * textarea
	 */
	private static function field_textarea( $args ) {

		$id = $args['id'];
		$name = IEBASE_HCB::DB_NAME['settings'] . '['. $id . ']';
		$value = IEBASE_HCB::$settings[$id];

		echo '<div class="hcb_field_textarea '. $id .'">' .
			'<textarea id="'. $id .'" name="'. $name . '" type="text" class="regular-text" rows="'. $args['rows'] . '" >'.
			$value .'</textarea>'. $args['after'].
		'</div>';
	}

	/**
	 * radio
	 */
	private static function field_radio( $args ) {

		$id = $args['id'];
		$name = IEBASE_HCB::DB_NAME['settings'] . '['. $id . ']';
		$value = IEBASE_HCB::$settings[$id];

		$fields = '';
		foreach ( $args['choices'] as $key => $val ) {
			$radio_id = $id .'_'. $val;
			$checked = checked( $value, $val, false );
			$props = 'name="'. $name .'" value="'. $val .'" '. $checked;

			$fields .= '<label for="'. $radio_id. '">'.
				'<input id="'. $radio_id .'" type="radio" '. $props . ' >'.
				'<span>'. $key. '</span>'.
			'</label><br>';
		}
		echo '<fieldset>'. $fields .'</fieldset>';
	}

	/**
	 * checkbox
	 */
	private static function field_checkbox( $args ) {

		$id = $args['id'];
		$name = IEBASE_HCB::DB_NAME['settings'] . '['. $id . ']';
		$value = IEBASE_HCB::$settings[$id];

		$checked = checked( $value, 'on', false );
		echo '<input type="hidden" name="'. $name.  '" value="off">'.
		'<input type="checkbox" id="'. $id. '" name="'. $name . '" value="on" '. $checked. ' />'.
		'<label for="'. $id. '">'. $args['label'] . '</label>';
	}
}

