<?php
if ( ! defined( 'ABSPATH' ) ) exit;

class IEBASE_HCB_Scripts {

	/**
	 * The constructor
	 */
	public function __construct() {
		add_action( 'init', ['IEBASE_HCB_Scripts', 'hook_init'] );
		add_action( 'wp_enqueue_scripts', ['IEBASE_HCB_Scripts', 'hook_wp_enqueue_scripts'], 20 );
		add_action( 'admin_enqueue_scripts', ['IEBASE_HCB_Scripts', 'hook_admin_enqueue_scripts'] );
		add_action( 'enqueue_block_editor_assets', ['IEBASE_HCB_Scripts', 'hook_enqueue_block_editor_assets'] );
		add_action( 'admin_head', ['IEBASE_HCB_Scripts', 'hook_admin_head'], 1 );
	}

	/**
	 * Register Block
	 */
	public static function hook_init() {

		// Block script registration
		$asset = include( IEBASE_HCB_PATH. 'assets/js/code-block/index.asset.php' );
		wp_register_script(
			'hcb-code-block',
			IEBASE_HCB_URL .'assets/js/code-block/index.js',
			$asset['dependencies'],
			$asset['version'],
			true
		);

		// Block registration
		$metadata = json_decode( file_get_contents( IEBASE_HCB_PATH . 'assets/js/code-block/block.json' ), true );
		$metadata = array_merge( $metadata, [ 'editor_script' => 'hcb-code-block' ] );
		register_block_type( 'iebase-hcb/code-block', $metadata );
	}


	/**
	 * Front Scripts
	 */
	public static function hook_wp_enqueue_scripts() {

		// HCB style
		//wp_enqueue_style( 'hcb-style', IEBASE_HCB_URL .'assets/css/hcb_style.css', [], IEBASE_HCB_VERSION );
		
		// Coloring style
		wp_enqueue_style( 'hcb-coloring', IEBASE_HCB::$coloring_css_url, [], IEBASE_HCB_VERSION );

		// Inline Style
		wp_add_inline_style( 'hcb-style', IEBASE_HCB_Scripts::get_inline_style() );

		// Prism.js
		wp_enqueue_script( 'hcb-prism', IEBASE_HCB::$prism_js_url, [], IEBASE_HCB_VERSION, true );

		// HCB script
		wp_enqueue_script( 'hcb-script', IEBASE_HCB_URL .'assets/js/hcb_script.js', ['hcb-prism'], IEBASE_HCB_VERSION, true );

	}


	/**
	 * Admin Scripts
	 */
	public static function hook_admin_enqueue_scripts( $hook_suffix ) {
		if ( 'settings_page_hcb_settings' === $hook_suffix ) {
			wp_enqueue_style( 'hcb-admin', IEBASE_HCB_URL .'assets/css/hcb_admin.css', [], IEBASE_HCB_VERSION );
		}
	}


	/**
	 * Block Scripts
	 */
	public static function hook_enqueue_block_editor_assets() {

		// Editor Style
		wp_enqueue_style( 
			'hcb-editor-style',
			IEBASE_HCB_URL .'assets/css/hcb_editor.css',
			[],
			IEBASE_HCB_VERSION
		);

		// Editor Coloring
		wp_enqueue_style( 
			'hcb-gutenberg-style',
			IEBASE_HCB::$editor_coloring_css_url,
			['hcb-editor-style'],
			IEBASE_HCB_VERSION
		);

		// Inline Style
		wp_add_inline_style( 'hcb-gutenberg-style', IEBASE_HCB_Scripts::get_inline_style( 'block' ) );

		// Empty file for translation registration
		wp_enqueue_script(
			'hcb-blocks',
			IEBASE_HCB_URL .'assets/js/hcb.js',
			[],
			IEBASE_HCB_VERSION,
			false
		);

		// Read translation file
		wp_set_script_translations(
			'hcb-blocks',
			'iebase-hcb',
			IEBASE_HCB_PATH . 'languages'
		);
	}


	/**
	 * Inline style generation
	 */
	public static function get_inline_style( $flag = 'front' ) {

		$inline_css = '';
		$hcb = IEBASE_HCB::$settings;

		if ( 'front' === $flag ) {
			// Code Lang
			if ( 'off' === $hcb[ 'show_lang' ] ) {
				$inline_css .= '.hcb_wrap pre:not([data-file]):not([data-show-lang])::before{ content: none;}';
			} 
		} elseif ( 'block' === $flag ) {
			// Code Lang
			if ( 'off' === IEBASE_HCB::$settings[ 'show_lang' ] ) {
				$inline_css .= '.hcb-block:not([data-file]):not([data-show-lang])::before{ content: none;}';
			}
		}
		return $inline_css;
	}


	/**
	 * Add code to Admin Head.
	 */
	public static function hook_admin_head() {

		$langs = IEBASE_HCB::$settings[ 'support_langs' ];
		$langs = mb_convert_kana( $langs, 'as'); //If there are full-width characters and spaces, convert to half-width
		$langs = str_replace(["\r\n", "\r", "\n"], '', $langs);
		$langs = trim( $langs, ',' );

		echo '<script id="hcb-langs">var hcbLangs = {'. trim( $langs ) .'};</script>' . PHP_EOL;
	}
}
